/*
 * Copyright (c) 1991-2001 Rational Software Corporation. All rights
 * reserved.
 * 
 * Rational, the Rational logo, ObjecTime (and logo) are registered
 * trademarks of Rational Software Corporation.
 * 
 * The placing of the copyright notices on Rational source code is not
 * intended to mean that they are published works, but are included in the
 * event of inadvertent publication. The source code of Rational contains
 * trade secrets and other valuable confidential information of Rational
 * Software Corporation. Rational Software Corporation and its licensors
 * retain ownership to Rational Products in both source and object code
 * format, and related documentation and all rights therein including
 * copyrights, patents and trade secrets.
 * 
 * 
 * U.S. Government Rights
 * 
 * Use, duplication, or disclosure by the U.S. Government is subject to
 * restrictions set forth in the applicable Rational License Agreement
 * and in DFARS 227.7202-1(a) and 227.7202-3(a) (1995), DFARS
 * 252.227-7013(c)(1)(ii)(Oct 1988), FAR 12.212(a) 1995, FAR 52.227-19,
 * or FAR 52.227-14, as applicable.
 * 
 * Unless otherwise agreed to in writing, use of Rational products is
 * governed by the Rational Product License Agreement provided with
 * the product.
 */

#include <RTDebugger.h>
#include <RTMemoryUtil.h>
#include <RTObserver.h>
#include <RTTcpSocket.h>
#include <stdio.h>


extern "C" void _atl_obstools_dump(int);
extern "C" unsigned char atl_initialized; /* VC7 need "C" */
/* extern unsigned char atl_initialized;  some other compilers not */

#ifndef RTRT_DUMP
#define RTRT_DUMP 510 /* to dump all then close the file immediately after the dump */
#endif

void RTObserver::cmdCommand( const char * commandString )
{
    // assume this is not a flow cmd (pause/resume will change this)
    lastFlowCmd = FlowNone;

    // run, step & stop are 'user' commands which all affect the
    // resumeToRun flag
    
    if(      0 == RTMemoryUtil::strcmp( commandString, "run"    ) )
    {
 haltByProbe = 0;
 resumeToRun = 1;
 debugger->proceed();
    }

    else if( 0 == RTMemoryUtil::strcmp( commandString, "step"   ) )
    {
 haltByProbe = 0;
 resumeToRun = 0;
 debugger->step( 1U );
    }

    else if( 0 == RTMemoryUtil::strcmp( commandString, "stop"   ) )
    {
 // RF modif for coverage

 haltByProbe = 0;
 resumeToRun = 0;
 debugger->step( 0U );
 if (atl_initialized == 2) {
  printf("TestRT dumping...\n"); 
  _atl_obstools_dump(RTRT_DUMP);
  printf("TestRT dump done, file closed\n"); 
 }
    }

    // pause is a 'system' command which doesn't affect the resumeToRun flag
    else if( 0 == RTMemoryUtil::strcmp( commandString, "pause"  ) )
    {
 lastFlowCmd = FlowPause;
 debugger->step( 0U );
    }

    // resume only runs if the last user command was run
    // AND execution was not halted by probe
    else if( 0 == RTMemoryUtil::strcmp( commandString, "resume" ) )
    {
 lastFlowCmd = FlowResume;
 if( resumeToRun && ! haltByProbe )
     debugger->proceed();
    }

    // exit terminates the executable, after closing down all the sockets
    else if( 0 == RTMemoryUtil::strcmp( commandString, "exit"   ) )
    {
 debugger->doCmdExit();
    }
}
