

/*
 *  Licensed Materials - Property of IBM
 *  Restricted Material of IBM
 *  IBM Rational Test RealTime
 *  (c) Copyright IBM Corp. 2003-2007 All Rights Reserved.
 *
 *  US Governement Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */


/*
 * %Copyright%
 */

#include <RTPriv/Daemon.h>
#include <RTPriv/Debugger.h>
#include <RTPriv/List.h>
#include <RTPriv/Observer.h>
#include <RTPubl/MemUtil.h>

extern void _atl_obstools_dump(int);
extern unsigned char atl_initialized;
#ifndef RTRT_DUMP
#define RTRT_DUMP 2 /* to close the file immediately after the dump */
#endif

void RTObserver_cmdCommand( RTObserver * this, const char * commandString )
{
    /* assume this is not a flow cmd (pause/resume will change this)
    */
    this->prot.lastFlowCmd = RTObserver_FlowNone;

    /* run, step & stop are 'user' commands which all affect the
    ** resumeToRun flag
    */
    if(      0 == RTMemoryUtil_strcmp( commandString, "run"    ) )
    {
	this->prot.haltByProbe = 0;
	this->prot.resumeToRun = 1;
	RTDebugger_proceed();
    }

    else if( 0 == RTMemoryUtil_strcmp( commandString, "step"   ) )
    {
	this->prot.haltByProbe = 0;
	this->prot.resumeToRun = 0;
	RTDebugger_step( 1U );
    }

    else if( 0 == RTMemoryUtil_strcmp( commandString, "stop"   ) )
    {
	this->prot.haltByProbe = 0;
	this->prot.resumeToRun = 0;
	RTDebugger_step( 0U );

 if (atl_initialized == 2) {
  printf("TestRT dumping...\n");
  _atl_obstools_dump(RTRT_DUMP);
  printf("TestRT dump done, file closed\n");
 }
    }

    /* pause is a 'system' command which doesn't affect the resumeToRun flag
    */
    else if( 0 == RTMemoryUtil_strcmp( commandString, "pause"  ) )
    {
	this->prot.lastFlowCmd = RTObserver_FlowPause;
	RTDebugger_step( 0U );
    }

    /* resume only runs if the last user command was run
    ** AND execution was not halted by probe
    */
    else if( 0 == RTMemoryUtil_strcmp( commandString, "resume" ) )
    {
	this->prot.lastFlowCmd = RTObserver_FlowResume;
	if( this->prot.resumeToRun && ! this->prot.haltByProbe )
	    RTDebugger_proceed();
    }

    /* exit terminates the executable, after closing down all the sockets
    */
    else if( 0 == RTMemoryUtil_strcmp( commandString, "exit"   ) )
    {
	RTDebugger_doCmdExit();
    }
}
